@@ -7,7 +7,7 @@ from .models import (
 )
 
 ACTIONS = """
-<a href="{% url "plugins:nautobot_evpn:es-delete" pk=record.pk %}" class="btn btn-danger"> <i class="mdi mdi-trash-can-outline"></i></a>
+<a href="{% url "plugins:nautobot_evpn:ethernetsegment_delete" pk=record.pk %}" class="btn btn-danger"> <i class="mdi mdi-trash-can-outline"></i></a>
 """
 
 
