@@ -1,13 +1,13 @@
-
 from nautobot.dcim.choices import InterfaceTypeChoices
 from nautobot.extras.plugins import PluginTemplateExtension
 from nautobot.ipam.models import VRF
 
 from .models import (
-    VRFPrimaryVLAN, VLANVRFList, EthernetSegmentMembership, EthernetSegment,
+    VRFPrimaryVLAN, VLANVRFList, EthernetSegmentMembership,
     AnycastIP
 )
 
+
 class VRFPrimaryVLANConnect(PluginTemplateExtension):
     model = 'ipam.vrf'
 
@@ -39,6 +39,7 @@ class VLANAddToVRF(PluginTemplateExtension):
             'vlanvrf': vlanvrf,
         })
 
+
 class InterfaceEthernetSegment(PluginTemplateExtension):
     model = 'dcim.interface'
 
@@ -83,6 +84,7 @@ class InterfaceEthernetSegment(PluginTemplateExtension):
             'es': es,
         })
 
+
 class DeviceSVITemplate(PluginTemplateExtension):
     model = 'dcim.device'
 
@@ -132,6 +134,7 @@ class DeviceSVITemplate(PluginTemplateExtension):
             'svis': svis,
         })
 
+
 template_extensions = [
     VRFPrimaryVLANConnect, VLANAddToVRF, InterfaceEthernetSegment, DeviceSVITemplate
 ]
