@@ -14,9 +14,11 @@ urlpatterns = [
     path(r'es-link/<uuid:pk>/add/', views.JoinEthernetSegmentView.as_view(), name='join-es'),
     path(r'es-link/<uuid:pk>/delete/', views.LeaveEthernetSegmentView.as_view(), name='leave-es'),
     path(r'esm/import/', views.EthernetSegmentMembershipImportView.as_view(), name='esm-import'),
-    path(r'es/', views.EthernetSegmentListView.as_view(), name='es-list'),
-    path(r'es/<uuid:pk>', views.EthernetSegmentView.as_view(), name='es'),
-    path(r'es/add/', views.EthernetSegmentAddView.as_view(), name='es-add'),
-    path(r'es/import/', views.EthernetSegmentImportView.as_view(), name='es-import'),
-    path(r'es/<uuid:pk>/delete/', views.EthernetSegmentDeleteView.as_view(), name='es-delete'),
+
+    path(r'es/', views.EthernetSegmentListView.as_view(), name='ethernetsegment_list'),
+    path(r'es/<uuid:pk>', views.EthernetSegmentView.as_view(), name='ethernetsegment'),
+    path(r'es/add/', views.EthernetSegmentAddView.as_view(), name='ethernetsegment_add'),
+    path(r'es/<uuid:pk>/edit/', views.EthernetSegmentAddView.as_view(), name='ethernetsegment_edit'),
+    path(r'es/import/', views.EthernetSegmentImportView.as_view(), name='ethernetsegment_import'),
+    path(r'es/<uuid:pk>/delete/', views.EthernetSegmentDeleteView.as_view(), name='ethernetsegment_delete'),
 ]
