@@ -167,7 +167,7 @@ class EthernetSegmentView(ObjectView):
     queryset = EthernetSegment.objects.all()
 
     def get_extra_context(self, request, instance):
-        attached_interfaces = Interface.objects.filter(ethernetsegmentmembership__segment=instance).restrict(
+        attached_interfaces = Interface.objects.filter(ethernet_segment_membership__segment=instance).restrict(
             request.user, "view")
 
         physical_interfaces = Interface.objects.filter(lag__in=attached_interfaces)
